package Starlink::Config;

=head1 NAME

Starlink::Config - Retrieve local Starlink configuration

=head1 SYNOPSIS

  use Starlink::Config;

  $star = $StarConfig{'Star'};
  $inc  = $StarConfig{'Star_Inc'};
  $lib  = $StarConfig{'Star_Lib'};
  $shlibs = $StarConfig{'Star_Share'};

=head1 DESCRIPTION

This package contains the location of the Starlink software
on your system. It is intended to simplify the building
of perl modules based on Starlink libraries and allows
for this information to be placed in a single place
rather than in every single Starlink module.

The locations of the relevant directories are set during build time.
The location of the Starlink directory is determined using 
environment variables: $STARLINK is used if present, else $INSTALL
is used, else C</star> is tried. If none of these directories
exists the build fails.

When used, a hash is imported into the current namespace called
C<%StarConfig>. This hash contains the following keys:

=over 4

=item Star

The root directory of the Starlink software installation.
This usually has a value of F</star>.

=item Star_Bin

The location for Starlink binary files. Usually
in F</star/bin>.

=item Star_Inc

The location of the Starlink include files. Usually
in F</star/include>.

=item Star_Lib

The location of the Starlink static libraries. Usually
in F</star/lib>.

=item Star_Share

The location of Starlink shared libraries. Usually
in F</star/share>.

=back

=head1 IMPLEMENTATION

C<%StarConfig> is implemented as a tied hash primarily to
make sure that the hash is read-only. The module
is automatically generated at build time and reflects
the state of the environment variables at that moment.

=head1 AUTHOR

Tim Jenness (t.jenness@jach.hawaii.edu)

=cut


use strict;
use Exporter ();
use vars qw/ %StarConfig @ISA @EXPORT $VERSION/;
@ISA = qw(Exporter);
@EXPORT = qw(%StarConfig);

$VERSION = '1.00';

# This is populated from <DATA>
my (%localConfig);

# use a tied hash so that we can enforce read-only

sub TIEHASH { bless \%localConfig; }

sub FETCH {
  $_[0]->{$_[1]};
}

sub FIRSTKEY { (each %{$_[0]})[0]; }
sub NEXTKEY  { (each( %{$_[0]} ))[0]; }
sub EXISTS   { exists($_[0]->{$_[1]}); }

# Readonly hash
sub STORE  { die "\%Starlink::Config::StarConfig is read-only\n" }
sub DELETE { &STORE }
sub CLEAR  { &STORE }
sub DESTROY { }

# Read the data into a lexical variable
foreach (<DATA>) {
  my ($key, $value) = split('\s*=>\s*');
  $value =~ s/\'//g;
  chomp($value);
  $localConfig{$key} = $value if defined $key;
}

tie %StarConfig, 'Starlink::Config';

1;

# Store the keys and values after the __DATA__ tag
# Can then simply append the information during
# makefile.PL creation
# Should be of the form Key => Value
__DATA__
Star =>       /usr/lib/star
Star_Inc   => /usr/lib/star/include
Star_Lib   => /usr/lib/star/lib
Star_Bin   => /usr/lib/star/bin
Star_Share => /usr/lib/star/share
